hyperspy\.misc\.eels package
============================

Submodules
----------

hyperspy\.misc\.eels\.base\_gos module
--------------------------------------

.. automodule:: hyperspy.misc.eels.base_gos
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.misc\.eels\.eelsdb module
-----------------------------------

.. automodule:: hyperspy.misc.eels.eelsdb
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.misc\.eels\.effective\_angle module
---------------------------------------------

.. automodule:: hyperspy.misc.eels.effective_angle
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.misc\.eels\.hartree\_slater\_gos module
-------------------------------------------------

.. automodule:: hyperspy.misc.eels.hartree_slater_gos
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.misc\.eels\.hydrogenic\_gos module
--------------------------------------------

.. automodule:: hyperspy.misc.eels.hydrogenic_gos
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.misc\.eels\.tools module
----------------------------------

.. automodule:: hyperspy.misc.eels.tools
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.misc.eels
    :members:
    :undoc-members:
    :show-inheritance:
